package main

import (
	"encoding/xml"
	"fmt"
	"os"
	"strings"
)

type OpenSearchDescription struct {
	XMLName     xml.Name `xml:"OpenSearchDescription"`
	Xmlns       string   `xml:"xmlns,attr"`
	ShortName   string   `xml:"ShortName"`
	Description string   `xml:"Description"`
	Tags        string   `xml:"Tags"`
	URL         URL      `xml:"Url"`
}

type URL struct {
	Type     string `xml:"type,attr"`
	Template string `xml:"template,attr"`
}

// isLocalAddress checks if the domain is a local address
func isLocalAddress(domain string) bool {
	return domain == "localhost" || strings.HasPrefix(domain, "127.") || strings.HasPrefix(domain, "192.168.") || strings.HasPrefix(domain, "10.")
}

func generateOpenSearchXML(config Config) {
	protocol := "https://"
	if isLocalAddress(config.Domain) {
		protocol = "http://"
	}

	opensearch := OpenSearchDescription{
		Xmlns:       "http://a9.com/-/spec/opensearch/1.1/",
		ShortName:   "Ocásek",
		Description: "Search engine",
		Tags:        "search, engine",
		URL: URL{
			Type:     "text/html",
			Template: fmt.Sprintf("%s%s/search?q={searchTerms}", protocol, config.Domain),
		},
	}

	file, err := os.Create("static/opensearch.xml")
	if err != nil {
		fmt.Println("Error creating OpenSearch file:", err)
		return
	}
	defer file.Close()

	enc := xml.NewEncoder(file)
	enc.Indent("  ", "    ")
	if err := enc.Encode(opensearch); err != nil {
		fmt.Println("Error encoding OpenSearch XML:", err)
		return
	}

	fmt.Println("OpenSearch description file generated successfully.")
}
